#include <dirent.h>
#include <app_preference.h>

#include "$(appName).h"
#include "data.h"
#include "conf.h"

static char *prefs[] = { KEY_PREFS_FAV1, KEY_PREFS_FAV2, KEY_PREFS_FAV3,
	KEY_PREFS_FAV4 };


static char *
__get_file_ext(const char *f_name);
static bool
__check_file_ext(const char *ext);

Eina_List *
data_get_available_images(void)
{
	char buf[PATH_MAX] = {0, };
	DIR *dir_h = NULL;
	struct dirent *dir_content = NULL;
	Eina_List *list = NULL;

	char *p_res_path = app_get_resource_path();
	if (!p_res_path) {
		dlog_print(DLOG_ERROR, LOG_TAG, "[FAILED][cannot read res dir]");
		return NULL;
	}

	snprintf(buf, sizeof(buf), "%simages", p_res_path);

	dir_h = opendir(buf);
	if (!dir_h) {
		dlog_print(DLOG_ERROR, LOG_TAG, "[FAILED][failed to opendir]");
		free(p_res_path);
		return NULL;
	}

	while ((dir_content = readdir(dir_h)) != NULL) {
		char *ext = __get_file_ext(dir_content->d_name);

		if (__check_file_ext(ext)) {
			bzero(buf, sizeof(buf));
			snprintf(buf, sizeof(buf), "%simages/%s", p_res_path,
				dir_content->d_name);
			list = eina_list_append(list, strdup(buf));
		}
	}

	closedir(dir_h);
	free(p_res_path);

	return list;
}

Eina_Bool
data_update_favorites(Eina_List *paths)
{
	Eina_List *it = NULL;
	char *file_path = NULL;
	int i = 0;
	preference_remove_all();

	EINA_LIST_FOREACH(paths, it, file_path) {
		if (!file_path)
			continue;

		preference_set_string(prefs[i++], file_path);
	}

	return EINA_TRUE;
}

static char *
__get_file_ext(const char *f_name)
{
	if (!f_name)
		return NULL;

	return strchr(f_name, '.');
}

static bool
__check_file_ext(const char *ext)
{
	if (!ext)
		return false;

	if (!strncmp(".jpg", ext, strlen(ext)))
		return true;

	return false;
}
